@@ -6,7 +6,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2017	PgPool Global Development Group
+ * Copyright (c) 2003-2015	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -25,7 +25,6 @@
 #include "utils/elog.h"
 #include "context/pool_process_context.h"
 #include "pool_config.h"		/* remove me afterwards */
-#include <unistd.h>
 
 static POOL_PROCESS_CONTEXT process_context_d;
 static POOL_PROCESS_CONTEXT *process_context;
@@ -196,6 +195,87 @@ ConnectionInfo *pool_coninfo_pid(int pid, int connection_pool, int backend)
 					 backend];
 }
 
+/*
+ * locate and return the shared memory ConnectionInfo having the
+ * backend connection with the pid
+ * if the connection is found the *backend_node_id contains the backend node id
+ * of the backend node that has the connection
+ */
+ConnectionInfo* pool_coninfo_backend_pid(int backend_pid, int* backend_node_id)
+{
+	int child;
+	/*
+	 * look for the child process that has the backend
+	 * with the pid
+	 */
+
+	ereport(DEBUG1,
+			(errmsg("searching for the connection with backend pid:%d",backend_pid)));
+
+	for (child = 0; child < pool_config->num_init_children; child++)
+	{
+		int pool;
+		ProcessInfo *pi = pool_get_process_info(process_info[child].pid);
+
+		for (pool = 0; pool < pool_config->max_pool; pool++)
+		{
+			int backend_id;
+			for (backend_id = 0; backend_id < NUM_BACKENDS; backend_id++)
+			{
+				int poolBE = pool*MAX_NUM_BACKENDS+backend_id;
+				if (ntohl(pi->connection_info[poolBE].pid) == backend_pid)
+				{
+					ereport(DEBUG1,
+							(errmsg("found for the connection with backend pid:%d on backend node %d",backend_pid,backend_id)));
+					*backend_node_id = backend_id;
+					return &pi->connection_info[poolBE];
+				}
+			}
+		}
+	}
+	return NULL;
+}
+
+/*
+ * returns true if the conInfo object belongs to the current child process
+ */
+bool pool_is_my_coninfo(ConnectionInfo* connInfo)
+{
+	int pool;
+	ProcessInfo *pi = pool_get_my_process_info();
+	for (pool = 0; pool < pool_config->max_pool; pool++)
+	{
+		int backend_id;
+		for (backend_id = 0; backend_id < NUM_BACKENDS; backend_id++)
+		{
+			int poolBE = pool*MAX_NUM_BACKENDS+backend_id;
+			ConnectionInfo* cInfo = &pi->connection_info[poolBE];
+			if (cInfo == connInfo)
+			{
+				ereport(DEBUG1,
+						(errmsg("connection Info object is local")));
+				return true;
+			}
+		}
+	}
+	return false;
+}
+
+/*
+ * sets the flag to mark that the connection will be terminated by the
+ * backend and it should not be considered as a backend node failure.
+ * This flag is used to handle pg_terminate_backend()
+ */
+void pool_set_connection_will_be_terminated(ConnectionInfo* connInfo)
+{
+	connInfo->swallow_termination = 1;
+}
+
+void pool_unset_connection_will_be_terminated(ConnectionInfo* connInfo)
+{
+	connInfo->swallow_termination = 0;
+}
+
 /*
  * Set frontend connected flag
  */
@@ -271,7 +351,7 @@ void pool_alarm(pool_sighandler_t handler, unsigned int second)
 /*
  * Undo the alarm signal handler using the remaining time.
  */
-void pool_undo_alarm(void)
+void pool_undo_alarm()
 {
 	POOL_PROCESS_CONTEXT *p = pool_get_process_context();
 
