@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2016	PgPool Global Development Group
+ * Copyright (c) 2003-2017	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -805,7 +805,7 @@ static int *create_inet_domain_sockets(const char *hostname, const int port)
 			errdetail("asprintf() failed: %s", strerror(errno))));
 	}
 
-	if ((ret = getaddrinfo(hostname, portstr, &hints, &res)) != 0)
+	if ((ret = getaddrinfo((!hostname || strcmp(hostname, "*") == 0) ? NULL : hostname, portstr, &hints, &res)) != 0)
 	{
 		ereport(FATAL,
 			(errmsg("failed to create INET domain socket"),
@@ -1076,7 +1076,7 @@ static void terminate_all_childrens()
     {
 		int ret_pid;
 
-        wpid = waitpid(-1, &ret_pid, WNOHANG);
+        wpid = waitpid(-1, &ret_pid, 0);
     } while (wpid > 0 || (wpid == -1 && errno == EINTR));
 
     if (wpid == -1 && errno != ECHILD)
@@ -1449,7 +1449,7 @@ static RETSIGTYPE exit_handler(int sig)
     {
 		int ret_pid;
 
-        wpid = waitpid(-1, &ret_pid, WNOHANG);
+        wpid = waitpid(-1, &ret_pid, 0);
     } while (wpid > 0 || (wpid == -1 && errno == EINTR));
 
     if (wpid == -1 && errno != ECHILD)
@@ -1506,9 +1506,14 @@ static RETSIGTYPE failover_handler(int sig)
 
 	POOL_SETMASK(&BlockSig);
 	failover_request = 1;
+
+	write(pipe_fds[1], "\0", 1);
+
+#ifdef NOT_USED
 	if(write(pipe_fds[1], "\0", 1) < 0)
         ereport(WARNING,
                 (errmsg("failover_handler: write to pipe failed with error \"%s\"", strerror(errno))));
+#endif
 
 	POOL_SETMASK(&UnBlockSig);
 
@@ -2233,9 +2238,17 @@ static RETSIGTYPE reap_handler(int sig)
 
 	POOL_SETMASK(&BlockSig);
 	sigchld_request = 1;
+
+	if (pipe_fds[1])
+	{
+		write(pipe_fds[1], "\0", 1);
+	}
+
+#ifdef NOT_USED
 	if(pipe_fds[1] && write(pipe_fds[1], "\0", 1) < 0)
         ereport(WARNING,
             (errmsg("reap_handler: write to pipe failed with error \"%s\"", strerror(errno))));
+#endif
 
 	POOL_SETMASK(&UnBlockSig);
 
@@ -2353,6 +2366,14 @@ static void reaper(void)
 			else
 				ereport(LOG,
 						(errmsg("%s process with pid: %d exits with status %d by signal %d", exiting_process_name, pid, status, WTERMSIG(status))));
+			/* If the watchdog process was terminated abonormally.
+			 * we need to set the cleanup flag so that the new watchdog process
+			 * can start without problems
+			 */
+			if (pool_config->use_watchdog && pid == watchdog_pid)
+			{
+				set_watchdog_process_needs_cleanup();
+			}
 		}
 		else
 			ereport(LOG,
@@ -2527,9 +2548,12 @@ static RETSIGTYPE wakeup_handler(int sig)
 	if (processState != INITIALIZING)
 	{
 		POOL_SETMASK(&BlockSig);
+		write(pipe_fds[1], "\0", 1);
+#ifdef NOT_USED
 		if(write(pipe_fds[1], "\0", 1) < 0)
 			ereport(WARNING,
 				(errmsg("wakeup_handler: write to pipe failed with error \"%s\"", strerror(errno))));
+#endif
 		POOL_SETMASK(&UnBlockSig);
 	}
 	errno = save_errno;
@@ -2545,9 +2569,12 @@ static RETSIGTYPE reload_config_handler(int sig)
 
 	POOL_SETMASK(&BlockSig);
 	reload_config_request = 1;
+	write(pipe_fds[1], "\0", 1);
+#ifdef NOT_USED
 	if(write(pipe_fds[1], "\0", 1) < 0)
         ereport(WARNING,
             (errmsg("reload_config_handler: write to pipe failed with error \"%s\"", strerror(errno))));
+#endif
 
 	POOL_SETMASK(&UnBlockSig);
 
